==> babel-0.0.3.tgz: package/src/index.ts <==
import type { NodePath, PluginObj } from "@babel/core";
import type { Program } from "@babel/types";
import template from "@babel/template";
import { declare } from "@babel/helper-plugin-utils";

const FUNCS_PATH = "cua.functions"; // TODO: configurable relative path
const CLIENT_PKG = "@cua.run/client";

let importedFuncs: string[] = [];
let clientImported = false;

let program: NodePath<Program>;
export default declare((api): PluginObj => {
  return {
    name: "cua.run",
    visitor: {
      ImportDeclaration: (path) => {
        if (path.node.importKind !== "value") {
          return;
        }
        if (path.node.source.value === CLIENT_PKG) {
          clientImported = true
        }
        else if (path.node.source.value.match(FUNCS_PATH)) {
          importedFuncs.push(
            ...path.node.specifiers
              .map(
                (sp) =>
                  sp.type === "ImportDefaultSpecifier" &&
                  ((sp.local as any).name || sp.local)
              )
              .filter((v) => !!v)
          );
          path.remove();
        }
      },
      Program(path) {
        program = path;
        clientImported = false
        importedFuncs = []
      },
      CallExpression(path) {
        console.log('CallExpression', clientImported)
        if (
          path.node.callee.type !== "Identifier" ||
          !importedFuncs.includes(path.node.callee.name)
        ) {
          return;
        }

        if (!clientImported) {
          const importDeclaration = template(`
            import %%importName%% from %%importPath%%
          `);
          program.unshiftContainer(
            "body",
            importDeclaration({
              importName: api.types.identifier("cua"),
              importPath: api.types.stringLiteral("@cua.run/client"),
            })
          );
          clientImported = true;
        }
        const pushDeclaration = template.statement(`cua.push(%%fn%%)`);
        path.replaceWith(
          pushDeclaration({
            fn: api.types.stringLiteral(path.node.callee.name),
          })
        );
      },
    },
  };
});

==> babel-0.0.4.tgz: package/src/index.ts <==
import type { NodePath, PluginObj } from "@babel/core";
import type { Program } from "@babel/types";
import template from "@babel/template";
import { declare } from "@babel/helper-plugin-utils";

const FUNCS_PATH = "cua.functions"; // TODO: configurable relative path
const CLIENT_PKG = "@cua.run/client";

let importedFuncs: string[] = [];
let clientImported = false;

let program: NodePath<Program>;
export default declare((api): PluginObj => {
  return {
    name: "cua.run",
    visitor: {
      ImportDeclaration: (path) => {
        if (path.node.importKind !== "value") {
          return;
        }
        if (path.node.source.value === CLIENT_PKG) {
          clientImported = true
        }
        else if (path.node.source.value.match(FUNCS_PATH)) {
          importedFuncs.push(
            ...path.node.specifiers
              .map(
                (sp) =>
                  sp.type === "ImportDefaultSpecifier" &&
                  ((sp.local as any).name || sp.local)
              )
              .filter((v) => !!v)
          );
          path.remove();
        }
      },
      Program(path) {
        program = path;
        clientImported = false
        importedFuncs = []
      },
      CallExpression(path) {
        if (
          path.node.callee.type !== "Identifier" ||
          !importedFuncs.includes(path.node.callee.name)
        ) {
          return;
        }

        if (!clientImported) {
          const importDeclaration = template(`
            import %%importName%% from %%importPath%%
          `);
          program.unshiftContainer(
            "body",
            importDeclaration({
              importName: api.types.identifier("cua"),
              importPath: api.types.stringLiteral("@cua.run/client"),
            })
          );
          clientImported = true;
        }
        const pushDeclaration = template.statement(`await cua.push(%%fn%%)`);
        path.replaceWith(
          pushDeclaration({
            fn: api.types.stringLiteral(path.node.callee.name),
          })
        );
      },
    },
  };
});
